# bech32m for Python

This is a straight port of @sipa's Python reference implementation of bech32 and bech32m.

Original can be found here: [https://github.com/sipa/bech32/tree/master/ref/python](https://github.com/sipa/bech32/tree/master/ref/python).
